"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.compute.v1.disk_pb2
import yandex.cloud.compute.v1.disk_placement_group_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetDiskPlacementGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_PLACEMENT_GROUP_ID_FIELD_NUMBER: builtins.int
    disk_placement_group_id: builtins.str
    """ID of the placement group to return.
    To get the placement group ID, use [DiskPlacementGroupService.List] request.
    """
    def __init__(
        self,
        *,
        disk_placement_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_placement_group_id", b"disk_placement_group_id"]) -> None: ...

global___GetDiskPlacementGroupRequest = GetDiskPlacementGroupRequest

@typing.final
class ListDiskPlacementGroupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list placement groups in.
    To get the folder ID, use [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListDiskPlacementGroupsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListDiskPlacementGroupsResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where:
    1. `<field>` is the field name. Currently you can use filtering only on the limited number of fields.
    2. `<operator>` is a logical operator, one of `=`, `!=`, `IN`, `NOT IN`.
    3. `<value>` represents a value.
    String values should be written in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    """
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    The default sorting order is ascending
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDiskPlacementGroupsRequest = ListDiskPlacementGroupsRequest

@typing.final
class ListDiskPlacementGroupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_PLACEMENT_GROUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListDiskPlacementGroupsRequest.page_size], use
    [next_page_token] as the value
    for the [ListDiskPlacementGroupsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def disk_placement_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.disk_placement_group_pb2.DiskPlacementGroup]:
        """Lists placement groups for the specified folder."""

    def __init__(
        self,
        *,
        disk_placement_groups: collections.abc.Iterable[yandex.cloud.compute.v1.disk_placement_group_pb2.DiskPlacementGroup] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_placement_groups", b"disk_placement_groups", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDiskPlacementGroupsResponse = ListDiskPlacementGroupsResponse

@typing.final
class CreateDiskPlacementGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    SPREAD_PLACEMENT_STRATEGY_FIELD_NUMBER: builtins.int
    PARTITION_PLACEMENT_STRATEGY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a placement group in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the placement group."""
    description: builtins.str
    """Description of the placement group."""
    zone_id: builtins.str
    """ID of the availability zone where the placement group resides.
    To get a list of available zones use the [yandex.cloud.compute.v1.ZoneService.List] request.
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def spread_placement_strategy(self) -> yandex.cloud.compute.v1.disk_placement_group_pb2.DiskSpreadPlacementStrategy:
        """Distribute disks over distinct failure domains."""

    @property
    def partition_placement_strategy(self) -> yandex.cloud.compute.v1.disk_placement_group_pb2.DiskPartitionPlacementStrategy:
        """Distribute disks over partitions."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zone_id: builtins.str = ...,
        spread_placement_strategy: yandex.cloud.compute.v1.disk_placement_group_pb2.DiskSpreadPlacementStrategy | None = ...,
        partition_placement_strategy: yandex.cloud.compute.v1.disk_placement_group_pb2.DiskPartitionPlacementStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["partition_placement_strategy", b"partition_placement_strategy", "placement_strategy", b"placement_strategy", "spread_placement_strategy", b"spread_placement_strategy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "partition_placement_strategy", b"partition_placement_strategy", "placement_strategy", b"placement_strategy", "spread_placement_strategy", b"spread_placement_strategy", "zone_id", b"zone_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["placement_strategy", b"placement_strategy"]) -> typing.Literal["spread_placement_strategy", "partition_placement_strategy"] | None: ...

global___CreateDiskPlacementGroupRequest = CreateDiskPlacementGroupRequest

@typing.final
class CreateDiskPlacementGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_PLACEMENT_GROUP_ID_FIELD_NUMBER: builtins.int
    disk_placement_group_id: builtins.str
    """ID of the placement group that is being created."""
    def __init__(
        self,
        *,
        disk_placement_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_placement_group_id", b"disk_placement_group_id"]) -> None: ...

global___CreateDiskPlacementGroupMetadata = CreateDiskPlacementGroupMetadata

@typing.final
class UpdateDiskPlacementGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DISK_PLACEMENT_GROUP_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    disk_placement_group_id: builtins.str
    """ID of the placement group to update.
    To get the placement group ID, use an [DiskPlacementGroupService.List] request.
    """
    name: builtins.str
    """Name of the placement group."""
    description: builtins.str
    """Description of the placement group."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the DiskPlacementGroup resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        The existing set of `labels` is completely replaced by the provided set.
        """

    def __init__(
        self,
        *,
        disk_placement_group_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "disk_placement_group_id", b"disk_placement_group_id", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateDiskPlacementGroupRequest = UpdateDiskPlacementGroupRequest

@typing.final
class UpdateDiskPlacementGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_PLACEMENT_GROUP_ID_FIELD_NUMBER: builtins.int
    disk_placement_group_id: builtins.str
    """ID of the placement group that is being updated."""
    def __init__(
        self,
        *,
        disk_placement_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_placement_group_id", b"disk_placement_group_id"]) -> None: ...

global___UpdateDiskPlacementGroupMetadata = UpdateDiskPlacementGroupMetadata

@typing.final
class DeleteDiskPlacementGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_PLACEMENT_GROUP_ID_FIELD_NUMBER: builtins.int
    disk_placement_group_id: builtins.str
    """ID of the placement group to delete.
    To get the placement group ID, use [DiskPlacementGroupService.List] request.
    """
    def __init__(
        self,
        *,
        disk_placement_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_placement_group_id", b"disk_placement_group_id"]) -> None: ...

global___DeleteDiskPlacementGroupRequest = DeleteDiskPlacementGroupRequest

@typing.final
class DeleteDiskPlacementGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_PLACEMENT_GROUP_ID_FIELD_NUMBER: builtins.int
    disk_placement_group_id: builtins.str
    """ID of the placement group that is being deleted."""
    def __init__(
        self,
        *,
        disk_placement_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_placement_group_id", b"disk_placement_group_id"]) -> None: ...

global___DeleteDiskPlacementGroupMetadata = DeleteDiskPlacementGroupMetadata

@typing.final
class ListDiskPlacementGroupDisksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_PLACEMENT_GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    disk_placement_group_id: builtins.str
    """ID of the placement group to list disks for.
    To get the placement group ID, use [DiskPlacementGroupService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListDiskPlacementGroupDisksResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListDiskPlacementGroupDisksResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        disk_placement_group_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_placement_group_id", b"disk_placement_group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDiskPlacementGroupDisksRequest = ListDiskPlacementGroupDisksRequest

@typing.final
class ListDiskPlacementGroupDisksResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISKS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is more than [ListDiskPlacementGroupDisksRequest.page_size], use
    [next_page_token] as the value
    for the [ListDiskPlacementGroupDisksRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def disks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.disk_pb2.Disk]:
        """Lists disks for the specified placement group."""

    def __init__(
        self,
        *,
        disks: collections.abc.Iterable[yandex.cloud.compute.v1.disk_pb2.Disk] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disks", b"disks", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDiskPlacementGroupDisksResponse = ListDiskPlacementGroupDisksResponse

@typing.final
class ListDiskPlacementGroupOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_PLACEMENT_GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    disk_placement_group_id: builtins.str
    """ID of the placement group to list operations for.
    To get the placement group ID, use [DiskPlacementGroupService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListDiskPlacementGroupOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListDiskPlacementGroupOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        disk_placement_group_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_placement_group_id", b"disk_placement_group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDiskPlacementGroupOperationsRequest = ListDiskPlacementGroupOperationsRequest

@typing.final
class ListDiskPlacementGroupOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListDiskPlacementGroupOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListDiskPlacementGroupOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified placement group."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListDiskPlacementGroupOperationsResponse = ListDiskPlacementGroupOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.billing.v1.budget_pb2
import yandex.cloud.billing.v1.budget_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class BudgetServiceStub:
    """A set of methods for managing Budget resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.budget_service_pb2.GetBudgetRequest,
        yandex.cloud.billing.v1.budget_pb2.Budget,
    ]
    """Returns the specified budget."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.budget_service_pb2.ListBudgetsRequest,
        yandex.cloud.billing.v1.budget_service_pb2.ListBudgetsResponse,
    ]
    """Retrieves the list of budgets corresponding to the specified billing account."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.budget_service_pb2.CreateBudgetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a budget for the specified billing account."""

class BudgetServiceAsyncStub:
    """A set of methods for managing Budget resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.budget_service_pb2.GetBudgetRequest,
        yandex.cloud.billing.v1.budget_pb2.Budget,
    ]
    """Returns the specified budget."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.budget_service_pb2.ListBudgetsRequest,
        yandex.cloud.billing.v1.budget_service_pb2.ListBudgetsResponse,
    ]
    """Retrieves the list of budgets corresponding to the specified billing account."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.budget_service_pb2.CreateBudgetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a budget for the specified billing account."""

class BudgetServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Budget resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.billing.v1.budget_service_pb2.GetBudgetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.billing.v1.budget_pb2.Budget, collections.abc.Awaitable[yandex.cloud.billing.v1.budget_pb2.Budget]]:
        """Returns the specified budget."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.billing.v1.budget_service_pb2.ListBudgetsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.billing.v1.budget_service_pb2.ListBudgetsResponse, collections.abc.Awaitable[yandex.cloud.billing.v1.budget_service_pb2.ListBudgetsResponse]]:
        """Retrieves the list of budgets corresponding to the specified billing account."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.billing.v1.budget_service_pb2.CreateBudgetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a budget for the specified billing account."""

def add_BudgetServiceServicer_to_server(servicer: BudgetServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.containerregistry.v1.scanner_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ScanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the Image to be scanned for vulnerabilities."""
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___ScanRequest = ScanRequest

@typing.final
class ScanMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCAN_RESULT_ID_FIELD_NUMBER: builtins.int
    scan_result_id: builtins.str
    """ID of the ScanResult that is being created."""
    def __init__(
        self,
        *,
        scan_result_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["scan_result_id", b"scan_result_id"]) -> None: ...

global___ScanMetadata = ScanMetadata

@typing.final
class GetScanResultRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCAN_RESULT_ID_FIELD_NUMBER: builtins.int
    scan_result_id: builtins.str
    """ID of the ScanResult to return."""
    def __init__(
        self,
        *,
        scan_result_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["scan_result_id", b"scan_result_id"]) -> None: ...

global___GetScanResultRequest = GetScanResultRequest

@typing.final
class GetLastScanResultRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the Image to get last finished ScanResult."""
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___GetLastScanResultRequest = GetLastScanResultRequest

@typing.final
class ListScanResultsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    REPOSITORY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    repository_id: builtins.str
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListRegistriesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListRegistriesResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [ScanResult.status] field.
    2. An `=` operator.
    3. The value in double quotes (`"`).
    """
    order_by: builtins.str
    """An order expression that orders resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [ScanResult.status] field.
    2. Order selector. Currently you can use ordering only on `ScanResult.status` field (critical first).
    """
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
        repository_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["id", b"id", "image_id", b"image_id", "repository_id", b"repository_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "id", b"id", "image_id", b"image_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token", "repository_id", b"repository_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["id", b"id"]) -> typing.Literal["image_id", "repository_id"] | None: ...

global___ListScanResultsRequest = ListScanResultsRequest

@typing.final
class ListScanResultsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCAN_RESULTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListImagesRequest.page_size], use
    the [next_page_token] as the value
    for the [ListImagesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def scan_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.containerregistry.v1.scanner_pb2.ScanResult]:
        """List of ScanResult resources."""

    def __init__(
        self,
        *,
        scan_results: collections.abc.Iterable[yandex.cloud.containerregistry.v1.scanner_pb2.ScanResult] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "scan_results", b"scan_results"]) -> None: ...

global___ListScanResultsResponse = ListScanResultsResponse

@typing.final
class ListVulnerabilitiesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCAN_RESULT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    scan_result_id: builtins.str
    """ID of the ScanResult to get list of vulnerabilities for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListRegistriesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListRegistriesResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [Vulnerability.severity] and [PackageVulnerability.name] fields.
    2. An `=` operator.
    3. The value in double quotes (`"`).
    """
    order_by: builtins.str
    """An order expression that orders resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [Vulnerability.severity] and [PackageVulnerability.name] fields.
    2. Order selector. Currently you can use ordering only on `Vulnerability.severity` field (recent first).
    """
    def __init__(
        self,
        *,
        scan_result_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token", "scan_result_id", b"scan_result_id"]) -> None: ...

global___ListVulnerabilitiesRequest = ListVulnerabilitiesRequest

@typing.final
class ListVulnerabilitiesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VULNERABILITIES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListImagesRequest.page_size], use
    the [next_page_token] as the value
    for the [ListImagesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def vulnerabilities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.containerregistry.v1.scanner_pb2.Vulnerability]:
        """List of Vulnerability resources."""

    def __init__(
        self,
        *,
        vulnerabilities: collections.abc.Iterable[yandex.cloud.containerregistry.v1.scanner_pb2.Vulnerability] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "vulnerabilities", b"vulnerabilities"]) -> None: ...

global___ListVulnerabilitiesResponse = ListVulnerabilitiesResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Template(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _State:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Template._State.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATE_UNSPECIFIED: Template._State.ValueType  # 0
        PENDING: Template._State.ValueType  # 1
        """Subscription template created but not active yet."""
        ACTIVE: Template._State.ValueType  # 2
        """Subscription template is active."""
        DEPRECATED: Template._State.ValueType  # 3
        """Subscription template deprecated."""
        DELETED: Template._State.ValueType  # 4
        """Subscription template deleted."""

    class State(_State, metaclass=_StateEnumTypeWrapper): ...
    STATE_UNSPECIFIED: Template.State.ValueType  # 0
    PENDING: Template.State.ValueType  # 1
    """Subscription template created but not active yet."""
    ACTIVE: Template.State.ValueType  # 2
    """Subscription template is active."""
    DEPRECATED: Template.State.ValueType  # 3
    """Subscription template deprecated."""
    DELETED: Template.State.ValueType  # 4
    """Subscription template deleted."""

    ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PUBLISHER_ID_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    TARIFF_ID_FIELD_NUMBER: builtins.int
    LICENSE_SKU_ID_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the subscription template."""
    version_id: builtins.str
    """Version of the subscription template."""
    name: builtins.str
    """Name of the subscription template."""
    publisher_id: builtins.str
    """ID of publisher."""
    product_id: builtins.str
    """ID of product."""
    tariff_id: builtins.str
    """ID of tariff."""
    license_sku_id: builtins.str
    """ID of subscription SKU."""
    period: builtins.str
    """Subscription period."""
    state: global___Template.State.ValueType
    """Subscription template state."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Update timestamp."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        version_id: builtins.str = ...,
        name: builtins.str = ...,
        publisher_id: builtins.str = ...,
        product_id: builtins.str = ...,
        tariff_id: builtins.str = ...,
        license_sku_id: builtins.str = ...,
        period: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        state: global___Template.State.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "id", b"id", "license_sku_id", b"license_sku_id", "name", b"name", "period", b"period", "product_id", b"product_id", "publisher_id", b"publisher_id", "state", b"state", "tariff_id", b"tariff_id", "updated_at", b"updated_at", "version_id", b"version_id"]) -> None: ...

global___Template = Template



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.dataproc.v1.common_pb2
import yandex.cloud.dataproc.v1.subcluster_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetSubclusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    SUBCLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Data Proc cluster that the subcluster belongs to."""
    subcluster_id: builtins.str
    """ID of the subcluster to return.

    To get a subcluster ID make a [SubclusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        subcluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "subcluster_id", b"subcluster_id"]) -> None: ...

global___GetSubclusterRequest = GetSubclusterRequest

@typing.final
class ListSubclustersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Data Proc cluster to list subclusters in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListSubclustersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListSubclustersResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters subclusters listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [Subcluster.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=dataproc123_subcluster456`.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListSubclustersRequest = ListSubclustersRequest

@typing.final
class ListSubclustersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBCLUSTERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListSubclustersRequest.page_size], use `next_page_token` as the value
    for the [ListSubclustersRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def subclusters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.dataproc.v1.subcluster_pb2.Subcluster]:
        """List of subclusters in the specified cluster."""

    def __init__(
        self,
        *,
        subclusters: collections.abc.Iterable[yandex.cloud.dataproc.v1.subcluster_pb2.Subcluster] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "subclusters", b"subclusters"]) -> None: ...

global___ListSubclustersResponse = ListSubclustersResponse

@typing.final
class CreateSubclusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    HOSTS_COUNT_FIELD_NUMBER: builtins.int
    AUTOSCALING_CONFIG_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Data Proc cluster to create a subcluster in.

    To get a cluster ID, make a [ClusterService.List] request.
    """
    name: builtins.str
    """Name of the subcluster. The name must be unique within the cluster. The name can't be
    changed when the subcluster is created.
    """
    role: yandex.cloud.dataproc.v1.subcluster_pb2.Role.ValueType
    """Role that is fulfilled by hosts of the subcluster."""
    subnet_id: builtins.str
    """ID of the VPC subnet used for hosts in the subcluster."""
    hosts_count: builtins.int
    """Number of hosts in the subcluster."""
    @property
    def resources(self) -> yandex.cloud.dataproc.v1.common_pb2.Resources:
        """Resources allocated for each host in the subcluster."""

    @property
    def autoscaling_config(self) -> yandex.cloud.dataproc.v1.subcluster_pb2.AutoscalingConfig:
        """Configuration for instance group based subclusters"""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        name: builtins.str = ...,
        role: yandex.cloud.dataproc.v1.subcluster_pb2.Role.ValueType = ...,
        resources: yandex.cloud.dataproc.v1.common_pb2.Resources | None = ...,
        subnet_id: builtins.str = ...,
        hosts_count: builtins.int = ...,
        autoscaling_config: yandex.cloud.dataproc.v1.subcluster_pb2.AutoscalingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["autoscaling_config", b"autoscaling_config", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["autoscaling_config", b"autoscaling_config", "cluster_id", b"cluster_id", "hosts_count", b"hosts_count", "name", b"name", "resources", b"resources", "role", b"role", "subnet_id", b"subnet_id"]) -> None: ...

global___CreateSubclusterRequest = CreateSubclusterRequest

@typing.final
class CreateSubclusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    SUBCLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster that the subcluster is being added to."""
    subcluster_id: builtins.str
    """ID of the subcluster that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        subcluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "subcluster_id", b"subcluster_id"]) -> None: ...

global___CreateSubclusterMetadata = CreateSubclusterMetadata

@typing.final
class UpdateSubclusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    SUBCLUSTER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    HOSTS_COUNT_FIELD_NUMBER: builtins.int
    DECOMMISSION_TIMEOUT_FIELD_NUMBER: builtins.int
    AUTOSCALING_CONFIG_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to update a subcluster in.

    To get a cluster ID, make a [ClusterService.List] request.
    """
    subcluster_id: builtins.str
    """ID of the subcluster to update.

    To get a subcluster ID, make a [SubclusterService.List] request.
    """
    name: builtins.str
    """New name for the subcluster. The name must be unique within the cluster."""
    hosts_count: builtins.int
    """New number of hosts in the subcluster."""
    decommission_timeout: builtins.int
    """Timeout to gracefully decommission nodes. In seconds. Default value: 0"""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the subcluster should be updated."""

    @property
    def resources(self) -> yandex.cloud.dataproc.v1.common_pb2.Resources:
        """New configuration of resources that should be allocated for each host in the subcluster."""

    @property
    def autoscaling_config(self) -> yandex.cloud.dataproc.v1.subcluster_pb2.AutoscalingConfig:
        """Configuration for instance group based subclusters"""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        subcluster_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        resources: yandex.cloud.dataproc.v1.common_pb2.Resources | None = ...,
        name: builtins.str = ...,
        hosts_count: builtins.int = ...,
        decommission_timeout: builtins.int = ...,
        autoscaling_config: yandex.cloud.dataproc.v1.subcluster_pb2.AutoscalingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["autoscaling_config", b"autoscaling_config", "resources", b"resources", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["autoscaling_config", b"autoscaling_config", "cluster_id", b"cluster_id", "decommission_timeout", b"decommission_timeout", "hosts_count", b"hosts_count", "name", b"name", "resources", b"resources", "subcluster_id", b"subcluster_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateSubclusterRequest = UpdateSubclusterRequest

@typing.final
class UpdateSubclusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    SUBCLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster whose subcluster is being updated."""
    subcluster_id: builtins.str
    """ID of the subcluster that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        subcluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "subcluster_id", b"subcluster_id"]) -> None: ...

global___UpdateSubclusterMetadata = UpdateSubclusterMetadata

@typing.final
class DeleteSubclusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    SUBCLUSTER_ID_FIELD_NUMBER: builtins.int
    DECOMMISSION_TIMEOUT_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to remove a subcluster from.

    To get a cluster ID, make a [ClusterService.List] request.
    """
    subcluster_id: builtins.str
    """ID of the subcluster to delete."""
    decommission_timeout: builtins.int
    """Timeout to gracefully decommission nodes. In seconds. Default value: 0"""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        subcluster_id: builtins.str = ...,
        decommission_timeout: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "decommission_timeout", b"decommission_timeout", "subcluster_id", b"subcluster_id"]) -> None: ...

global___DeleteSubclusterRequest = DeleteSubclusterRequest

@typing.final
class DeleteSubclusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    SUBCLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster whose subcluster is being deleted."""
    subcluster_id: builtins.str
    """ID of the subcluster that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        subcluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "subcluster_id", b"subcluster_id"]) -> None: ...

global___DeleteSubclusterMetadata = DeleteSubclusterMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v2/community_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.datasphere.v2 import community_pb2 as yandex_dot_cloud_dot_datasphere_dot_v2_dot_community__pb2
from yandex.cloud.datasphere.v2 import resource_types_pb2 as yandex_dot_cloud_dot_datasphere_dot_v2_dot_resource__types__pb2
from yandex.cloud.datasphere.v2 import restrictions_pb2 as yandex_dot_cloud_dot_datasphere_dot_v2_dot_restrictions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/datasphere/v2/community_service.proto\x12\x1ayandex.cloud.datasphere.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/operation/operation.proto\x1a*yandex/cloud/datasphere/v2/community.proto\x1a/yandex/cloud/datasphere/v2/resource_types.proto\x1a-yandex/cloud/datasphere/v2/restrictions.proto\"\xca\x02\n\x16\x43reateCommunityRequest\x12J\n\x04name\x18\x01 \x01(\tB<\xf2\xc7\x31\x30[a-zA-Z0-9\xd0\x81\xd1\x91\xd0\x90-\xd1\x8f]\\S{1,61}[a-zA-Z0-9\xd0\x81\xd1\x91\xd0\x90-\xd1\x8f]\x8a\xc8\x31\x04<=63\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1d\n\x0forganization_id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x12\x62illing_account_id\x18\x04 \x01(\t\x12N\n\x06labels\x18\x05 \x03(\x0b\x32>.yandex.cloud.datasphere.v2.CreateCommunityRequest.LabelsEntry\x12\x15\n\x07zone_id\x18\x06 \x01(\tB\x04\xe8\xc7\x31\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x17\x43reateCommunityMetadata\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\t\"1\n\x13GetCommunityRequest\x12\x1a\n\x0c\x63ommunity_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x87\x02\n\x16UpdateCommunityRequest\x12\x1a\n\x0c\x63ommunity_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12N\n\x06labels\x18\x05 \x03(\x0b\x32>.yandex.cloud.datasphere.v2.UpdateCommunityRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x17UpdateCommunityMetadata\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\t\"4\n\x16\x44\x65leteCommunityRequest\x12\x1a\n\x0c\x63ommunity_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"/\n\x17\x44\x65leteCommunityMetadata\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\t\"\xb3\x01\n\x16ListCommunitiesRequest\x12\x11\n\tpage_size\x18\x01 \x01(\x03\x12\x12\n\npage_token\x18\x02 \x01(\t\x12#\n\x1bname_or_description_pattern\x18\x03 \x01(\t\x12\x13\n\x0bowned_by_id\x18\x05 \x01(\t\x12\x13\n\x0blist_public\x18\x06 \x01(\x08\x12\x1d\n\x0forganization_id\x18\x07 \x01(\tB\x04\xe8\xc7\x31\x01J\x04\x08\x04\x10\x05\"n\n\x17ListCommunitiesResponse\x12:\n\x0b\x63ommunities\x18\x01 \x03(\x0b\x32%.yandex.cloud.datasphere.v2.Community\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\":\n\"SetCommunityAccessBindingsMetadata\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\t\"=\n%UpdateCommunityAccessBindingsMetadata\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\t\"\xa3\x01\n\x1b\x41\x64\x64\x43ommunityResourceRequest\x12\"\n\x0c\x63ommunity_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x45\n\rresource_type\x18\x02 \x01(\x0e\x32(.yandex.cloud.datasphere.v2.ResourceTypeB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bresource_id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"\xa6\x01\n\x1eRemoveCommunityResourceRequest\x12\"\n\x0c\x63ommunity_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x45\n\rresource_type\x18\x02 \x01(\x0e\x32(.yandex.cloud.datasphere.v2.ResourceTypeB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bresource_id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"=\n\x1fGetCommunityRestrictionsRequest\x12\x1a\n\x0c\x63ommunity_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"|\n\x1fSetCommunityRestrictionsRequest\x12\x1a\n\x0c\x63ommunity_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12=\n\x0crestrictions\x18\x02 \x03(\x0b\x32\'.yandex.cloud.datasphere.v2.Restriction2\xe6\x13\n\x10\x43ommunityService\x12\xae\x01\n\x06\x43reate\x12\x32.yandex.cloud.datasphere.v2.CreateCommunityRequest\x1a!.yandex.cloud.operation.Operation\"M\xb2\xd2*$\n\x17\x43reateCommunityMetadata\x12\tCommunity\x82\xd3\xe4\x93\x02\x1f\"\x1a/datasphere/v2/communities:\x01*\x12\x90\x01\n\x03Get\x12/.yandex.cloud.datasphere.v2.GetCommunityRequest\x1a%.yandex.cloud.datasphere.v2.Community\"1\x82\xd3\xe4\x93\x02+\x12)/datasphere/v2/communities/{community_id}\x12\xbd\x01\n\x06Update\x12\x32.yandex.cloud.datasphere.v2.UpdateCommunityRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*$\n\x17UpdateCommunityMetadata\x12\tCommunity\x82\xd3\xe4\x93\x02.2)/datasphere/v2/communities/{community_id}:\x01*\x12\xc6\x01\n\x06\x44\x65lete\x12\x32.yandex.cloud.datasphere.v2.DeleteCommunityRequest\x1a!.yandex.cloud.operation.Operation\"e\xb2\xd2*0\n\x17\x44\x65leteCommunityMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02+*)/datasphere/v2/communities/{community_id}\x12\x93\x01\n\x04List\x12\x32.yandex.cloud.datasphere.v2.ListCommunitiesRequest\x1a\x33.yandex.cloud.datasphere.v2.ListCommunitiesResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/datasphere/v2/communities\x12\xb6\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/datasphere/v2/communities/{resource_id}:accessBindings\x12\xec\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x84\x01\xb2\xd2*;\n\"SetCommunityAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02?\":/datasphere/v2/communities/{resource_id}:setAccessBindings:\x01*\x12\xf8\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8a\x01\xb2\xd2*>\n%UpdateCommunityAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x42\x32=/datasphere/v2/communities/{resource_id}:updateAccessBindings:\x01*\x12\xc5\x01\n\x0b\x41\x64\x64Resource\x12\x37.yandex.cloud.datasphere.v2.AddCommunityResourceRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*\x17\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x39\"4/datasphere/v2/communities/{resource_id}:addResource:\x01*\x12\xce\x01\n\x0eRemoveResource\x12:.yandex.cloud.datasphere.v2.RemoveCommunityResourceRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*\x17\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02<\"7/datasphere/v2/communities/{resource_id}:removeResource:\x01*\x12\x9b\x01\n\x13GetRestrictionsMeta\x12\x16.google.protobuf.Empty\x1a\x37.yandex.cloud.datasphere.v2.GetRestrictionsMetaResponse\"3\x82\xd3\xe4\x93\x02-\x12+/datasphere/v2/communities/restrictionsMeta\x12\xc0\x01\n\x0fGetRestrictions\x12;.yandex.cloud.datasphere.v2.GetCommunityRestrictionsRequest\x1a\x30.yandex.cloud.datasphere.v2.RestrictionsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/datasphere/v2/communities/{community_id}:restrictions\x12\xd1\x01\n\x0fSetRestrictions\x12;.yandex.cloud.datasphere.v2.SetCommunityRestrictionsRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*\x16\x12\x14RestrictionsResponse\x82\xd3\xe4\x93\x02>\"9/datasphere/v2/communities/{community_id}:setRestrictions:\x01*Bk\n\x1eyandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v2.community_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036yandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphere'
  _CREATECOMMUNITYREQUEST_LABELSENTRY._options = None
  _CREATECOMMUNITYREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECOMMUNITYREQUEST.fields_by_name['name']._options = None
  _CREATECOMMUNITYREQUEST.fields_by_name['name']._serialized_options = b'\362\30710[a-zA-Z0-9\320\201\321\221\320\220-\321\217]\\S{1,61}[a-zA-Z0-9\320\201\321\221\320\220-\321\217]\212\3101\004<=63'
  _CREATECOMMUNITYREQUEST.fields_by_name['organization_id']._options = None
  _CREATECOMMUNITYREQUEST.fields_by_name['organization_id']._serialized_options = b'\350\3071\001'
  _CREATECOMMUNITYREQUEST.fields_by_name['zone_id']._options = None
  _CREATECOMMUNITYREQUEST.fields_by_name['zone_id']._serialized_options = b'\350\3071\001'
  _GETCOMMUNITYREQUEST.fields_by_name['community_id']._options = None
  _GETCOMMUNITYREQUEST.fields_by_name['community_id']._serialized_options = b'\350\3071\001'
  _UPDATECOMMUNITYREQUEST_LABELSENTRY._options = None
  _UPDATECOMMUNITYREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECOMMUNITYREQUEST.fields_by_name['community_id']._options = None
  _UPDATECOMMUNITYREQUEST.fields_by_name['community_id']._serialized_options = b'\350\3071\001'
  _DELETECOMMUNITYREQUEST.fields_by_name['community_id']._options = None
  _DELETECOMMUNITYREQUEST.fields_by_name['community_id']._serialized_options = b'\350\3071\001'
  _LISTCOMMUNITIESREQUEST.fields_by_name['organization_id']._options = None
  _LISTCOMMUNITIESREQUEST.fields_by_name['organization_id']._serialized_options = b'\350\3071\001'
  _ADDCOMMUNITYRESOURCEREQUEST.fields_by_name['community_id']._options = None
  _ADDCOMMUNITYRESOURCEREQUEST.fields_by_name['community_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ADDCOMMUNITYRESOURCEREQUEST.fields_by_name['resource_type']._options = None
  _ADDCOMMUNITYRESOURCEREQUEST.fields_by_name['resource_type']._serialized_options = b'\350\3071\001'
  _ADDCOMMUNITYRESOURCEREQUEST.fields_by_name['resource_id']._options = None
  _ADDCOMMUNITYRESOURCEREQUEST.fields_by_name['resource_id']._serialized_options = b'\350\3071\001'
  _REMOVECOMMUNITYRESOURCEREQUEST.fields_by_name['community_id']._options = None
  _REMOVECOMMUNITYRESOURCEREQUEST.fields_by_name['community_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _REMOVECOMMUNITYRESOURCEREQUEST.fields_by_name['resource_type']._options = None
  _REMOVECOMMUNITYRESOURCEREQUEST.fields_by_name['resource_type']._serialized_options = b'\350\3071\001'
  _REMOVECOMMUNITYRESOURCEREQUEST.fields_by_name['resource_id']._options = None
  _REMOVECOMMUNITYRESOURCEREQUEST.fields_by_name['resource_id']._serialized_options = b'\350\3071\001'
  _GETCOMMUNITYRESTRICTIONSREQUEST.fields_by_name['community_id']._options = None
  _GETCOMMUNITYRESTRICTIONSREQUEST.fields_by_name['community_id']._serialized_options = b'\350\3071\001'
  _SETCOMMUNITYRESTRICTIONSREQUEST.fields_by_name['community_id']._options = None
  _SETCOMMUNITYRESTRICTIONSREQUEST.fields_by_name['community_id']._serialized_options = b'\350\3071\001'
  _COMMUNITYSERVICE.methods_by_name['Create']._options = None
  _COMMUNITYSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*$\n\027CreateCommunityMetadata\022\tCommunity\202\323\344\223\002\037\"\032/datasphere/v2/communities:\001*'
  _COMMUNITYSERVICE.methods_by_name['Get']._options = None
  _COMMUNITYSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002+\022)/datasphere/v2/communities/{community_id}'
  _COMMUNITYSERVICE.methods_by_name['Update']._options = None
  _COMMUNITYSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*$\n\027UpdateCommunityMetadata\022\tCommunity\202\323\344\223\002.2)/datasphere/v2/communities/{community_id}:\001*'
  _COMMUNITYSERVICE.methods_by_name['Delete']._options = None
  _COMMUNITYSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*0\n\027DeleteCommunityMetadata\022\025google.protobuf.Empty\202\323\344\223\002+*)/datasphere/v2/communities/{community_id}'
  _COMMUNITYSERVICE.methods_by_name['List']._options = None
  _COMMUNITYSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\034\022\032/datasphere/v2/communities'
  _COMMUNITYSERVICE.methods_by_name['ListAccessBindings']._options = None
  _COMMUNITYSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0029\0227/datasphere/v2/communities/{resource_id}:accessBindings'
  _COMMUNITYSERVICE.methods_by_name['SetAccessBindings']._options = None
  _COMMUNITYSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*;\n\"SetCommunityAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002?\":/datasphere/v2/communities/{resource_id}:setAccessBindings:\001*'
  _COMMUNITYSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _COMMUNITYSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*>\n%UpdateCommunityAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002B2=/datasphere/v2/communities/{resource_id}:updateAccessBindings:\001*'
  _COMMUNITYSERVICE.methods_by_name['AddResource']._options = None
  _COMMUNITYSERVICE.methods_by_name['AddResource']._serialized_options = b'\262\322*\027\022\025google.protobuf.Empty\202\323\344\223\0029\"4/datasphere/v2/communities/{resource_id}:addResource:\001*'
  _COMMUNITYSERVICE.methods_by_name['RemoveResource']._options = None
  _COMMUNITYSERVICE.methods_by_name['RemoveResource']._serialized_options = b'\262\322*\027\022\025google.protobuf.Empty\202\323\344\223\002<\"7/datasphere/v2/communities/{resource_id}:removeResource:\001*'
  _COMMUNITYSERVICE.methods_by_name['GetRestrictionsMeta']._options = None
  _COMMUNITYSERVICE.methods_by_name['GetRestrictionsMeta']._serialized_options = b'\202\323\344\223\002-\022+/datasphere/v2/communities/restrictionsMeta'
  _COMMUNITYSERVICE.methods_by_name['GetRestrictions']._options = None
  _COMMUNITYSERVICE.methods_by_name['GetRestrictions']._serialized_options = b'\202\323\344\223\0028\0226/datasphere/v2/communities/{community_id}:restrictions'
  _COMMUNITYSERVICE.methods_by_name['SetRestrictions']._options = None
  _COMMUNITYSERVICE.methods_by_name['SetRestrictions']._serialized_options = b'\262\322*\026\022\024RestrictionsResponse\202\323\344\223\002>\"9/datasphere/v2/communities/{community_id}:setRestrictions:\001*'
  _globals['_CREATECOMMUNITYREQUEST']._serialized_start=455
  _globals['_CREATECOMMUNITYREQUEST']._serialized_end=785
  _globals['_CREATECOMMUNITYREQUEST_LABELSENTRY']._serialized_start=740
  _globals['_CREATECOMMUNITYREQUEST_LABELSENTRY']._serialized_end=785
  _globals['_CREATECOMMUNITYMETADATA']._serialized_start=787
  _globals['_CREATECOMMUNITYMETADATA']._serialized_end=834
  _globals['_GETCOMMUNITYREQUEST']._serialized_start=836
  _globals['_GETCOMMUNITYREQUEST']._serialized_end=885
  _globals['_UPDATECOMMUNITYREQUEST']._serialized_start=888
  _globals['_UPDATECOMMUNITYREQUEST']._serialized_end=1151
  _globals['_UPDATECOMMUNITYREQUEST_LABELSENTRY']._serialized_start=740
  _globals['_UPDATECOMMUNITYREQUEST_LABELSENTRY']._serialized_end=785
  _globals['_UPDATECOMMUNITYMETADATA']._serialized_start=1153
  _globals['_UPDATECOMMUNITYMETADATA']._serialized_end=1200
  _globals['_DELETECOMMUNITYREQUEST']._serialized_start=1202
  _globals['_DELETECOMMUNITYREQUEST']._serialized_end=1254
  _globals['_DELETECOMMUNITYMETADATA']._serialized_start=1256
  _globals['_DELETECOMMUNITYMETADATA']._serialized_end=1303
  _globals['_LISTCOMMUNITIESREQUEST']._serialized_start=1306
  _globals['_LISTCOMMUNITIESREQUEST']._serialized_end=1485
  _globals['_LISTCOMMUNITIESRESPONSE']._serialized_start=1487
  _globals['_LISTCOMMUNITIESRESPONSE']._serialized_end=1597
  _globals['_SETCOMMUNITYACCESSBINDINGSMETADATA']._serialized_start=1599
  _globals['_SETCOMMUNITYACCESSBINDINGSMETADATA']._serialized_end=1657
  _globals['_UPDATECOMMUNITYACCESSBINDINGSMETADATA']._serialized_start=1659
  _globals['_UPDATECOMMUNITYACCESSBINDINGSMETADATA']._serialized_end=1720
  _globals['_ADDCOMMUNITYRESOURCEREQUEST']._serialized_start=1723
  _globals['_ADDCOMMUNITYRESOURCEREQUEST']._serialized_end=1886
  _globals['_REMOVECOMMUNITYRESOURCEREQUEST']._serialized_start=1889
  _globals['_REMOVECOMMUNITYRESOURCEREQUEST']._serialized_end=2055
  _globals['_GETCOMMUNITYRESTRICTIONSREQUEST']._serialized_start=2057
  _globals['_GETCOMMUNITYRESTRICTIONSREQUEST']._serialized_end=2118
  _globals['_SETCOMMUNITYRESTRICTIONSREQUEST']._serialized_start=2120
  _globals['_SETCOMMUNITYRESTRICTIONSREQUEST']._serialized_end=2244
  _globals['_COMMUNITYSERVICE']._serialized_start=2247
  _globals['_COMMUNITYSERVICE']._serialized_end=4781
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/speechsense/v1/analysis/summarization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/speechsense/v1/analysis/summarization.proto\x12$yandex.cloud.speechsense.v1.analysis\"a\n\rSummarization\x12P\n\nstatements\x18\x01 \x03(\x0b\x32<.yandex.cloud.speechsense.v1.analysis.SummarizationStatement\"s\n\x16SummarizationStatement\x12G\n\x05\x66ield\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.speechsense.v1.analysis.SummarizationField\x12\x10\n\x08response\x18\x02 \x03(\t\"z\n\x12SummarizationField\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t\x12J\n\x04type\x18\x02 \x01(\x0e\x32<.yandex.cloud.speechsense.v1.analysis.SummarizationFieldType*\\\n\x16SummarizationFieldType\x12(\n$SUMMARIZATION_FIELD_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04TEXT\x10\x01\x12\x0e\n\nTEXT_ARRAY\x10\x02\x42\x94\x01\n(yandex.cloud.api.speechsense.v1.analysisB\x12SummarizationProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.analysis.summarization_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.speechsense.v1.analysisB\022SummarizationProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsense'
  _globals['_SUMMARIZATIONFIELDTYPE']._serialized_start=438
  _globals['_SUMMARIZATIONFIELDTYPE']._serialized_end=530
  _globals['_SUMMARIZATION']._serialized_start=98
  _globals['_SUMMARIZATION']._serialized_end=195
  _globals['_SUMMARIZATIONSTATEMENT']._serialized_start=197
  _globals['_SUMMARIZATIONSTATEMENT']._serialized_end=312
  _globals['_SUMMARIZATIONFIELD']._serialized_start=314
  _globals['_SUMMARIZATIONFIELD']._serialized_end=436
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.backup.v1.resource_pb2
import yandex.cloud.operation.operation_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListResourcesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID."""
    page_size: builtins.int
    """Number of results per page."""
    page_token: builtins.str
    """Token for the results page."""
    type: yandex.cloud.backup.v1.resource_pb2.ResourceType.ValueType
    """Type of resource. Could be compute VM or baremetal server."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        type: yandex.cloud.backup.v1.resource_pb2.ResourceType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token", "type", b"type"]) -> None: ...

global___ListResourcesRequest = ListResourcesRequest

@typing.final
class ListResourcesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for the next results page."""
    @property
    def resources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.backup.v1.resource_pb2.Resource]:
        """Set of resource parameters."""

    def __init__(
        self,
        *,
        resources: collections.abc.Iterable[yandex.cloud.backup.v1.resource_pb2.Resource] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "resources", b"resources"]) -> None: ...

global___ListResourcesResponse = ListResourcesResponse

@typing.final
class GetResourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    def __init__(
        self,
        *,
        compute_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id"]) -> None: ...

global___GetResourceRequest = GetResourceRequest

@typing.final
class GetResourceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_FIELD_NUMBER: builtins.int
    @property
    def resource(self) -> yandex.cloud.backup.v1.resource_pb2.Resource:
        """Set of resource parameters."""

    def __init__(
        self,
        *,
        resource: yandex.cloud.backup.v1.resource_pb2.Resource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource", b"resource"]) -> None: ...

global___GetResourceResponse = GetResourceResponse

@typing.final
class DeleteResourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    resource_id: builtins.str
    """Resource ID is used to identify Compute Cloud instance in backup service."""
    def __init__(
        self,
        *,
        compute_instance_id: builtins.str = ...,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "resource_id", b"resource_id"]) -> None: ...

global___DeleteResourceRequest = DeleteResourceRequest

@typing.final
class DeleteResourceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    def __init__(
        self,
        *,
        compute_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id"]) -> None: ...

global___DeleteResourceMetadata = DeleteResourceMetadata

@typing.final
class ListTasksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    page_size: builtins.int
    """Number of results per page."""
    page_token: builtins.str
    """Token for the results page."""
    def __init__(
        self,
        *,
        compute_instance_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListTasksRequest = ListTasksRequest

@typing.final
class ListTasksResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASKS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for the next results page."""
    @property
    def tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.backup.v1.resource_pb2.Task]:
        """Set of tasks parameters."""

    def __init__(
        self,
        *,
        tasks: collections.abc.Iterable[yandex.cloud.backup.v1.resource_pb2.Task] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "tasks", b"tasks"]) -> None: ...

global___ListTasksResponse = ListTasksResponse

@typing.final
class ListDirectoryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID."""
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    path: builtins.str
    """Path to list items in."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        compute_instance_id: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "folder_id", b"folder_id", "path", b"path"]) -> None: ...

global___ListDirectoryRequest = ListDirectoryRequest

@typing.final
class ListDirectoryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class FilesystemItem(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Type:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ListDirectoryResponse.FilesystemItem._Type.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            TYPE_UNSPECIFIED: ListDirectoryResponse.FilesystemItem._Type.ValueType  # 0
            VOLUME: ListDirectoryResponse.FilesystemItem._Type.ValueType  # 1
            DIRECTORY: ListDirectoryResponse.FilesystemItem._Type.ValueType  # 2
            FILE: ListDirectoryResponse.FilesystemItem._Type.ValueType  # 3

        class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
        TYPE_UNSPECIFIED: ListDirectoryResponse.FilesystemItem.Type.ValueType  # 0
        VOLUME: ListDirectoryResponse.FilesystemItem.Type.ValueType  # 1
        DIRECTORY: ListDirectoryResponse.FilesystemItem.Type.ValueType  # 2
        FILE: ListDirectoryResponse.FilesystemItem.Type.ValueType  # 3

        NAME_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        FILE_TYPE_FIELD_NUMBER: builtins.int
        SIZE_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Item name."""
        type: global___ListDirectoryResponse.FilesystemItem.Type.ValueType
        """Might be Volume, Directory of File."""
        file_type: global___ListDirectoryResponse.FilesystemItem.Type.ValueType
        """Might be Directory or File."""
        size: builtins.int
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            type: global___ListDirectoryResponse.FilesystemItem.Type.ValueType = ...,
            file_type: global___ListDirectoryResponse.FilesystemItem.Type.ValueType = ...,
            size: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["file_type", b"file_type", "name", b"name", "size", b"size", "type", b"type"]) -> None: ...

    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListDirectoryResponse.FilesystemItem]: ...
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___ListDirectoryResponse.FilesystemItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["items", b"items"]) -> None: ...

global___ListDirectoryResponse = ListDirectoryResponse

@typing.final
class CreateDirectoryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID."""
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    path: builtins.str
    """Path to create directory in."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        compute_instance_id: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "folder_id", b"folder_id", "path", b"path"]) -> None: ...

global___CreateDirectoryRequest = CreateDirectoryRequest

@typing.final
class CreateDirectoryMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    path: builtins.str
    """Path to create directory metadata in."""
    def __init__(
        self,
        *,
        compute_instance_id: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "path", b"path"]) -> None: ...

global___CreateDirectoryMetadata = CreateDirectoryMetadata

@typing.final
class ListResourceOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    page_size: builtins.int
    """Number of results per page."""
    page_token: builtins.str
    """Token for the results page."""
    def __init__(
        self,
        *,
        compute_instance_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListResourceOperationsRequest = ListResourceOperationsRequest

@typing.final
class ListResourceOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for the next results page."""
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified instance."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListResourceOperationsResponse = ListResourceOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.containerregistry.v1.registry_pb2
import yandex.cloud.containerregistry.v1.registry_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class RegistryServiceStub:
    """A set of methods for managing Registry resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.registry_service_pb2.GetRegistryRequest,
        yandex.cloud.containerregistry.v1.registry_pb2.Registry,
    ]
    """Returns the specified Registry resource.

    To get the list of available Registry resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.registry_service_pb2.ListRegistriesRequest,
        yandex.cloud.containerregistry.v1.registry_service_pb2.ListRegistriesResponse,
    ]
    """Retrieves the list of Registry resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.registry_service_pb2.CreateRegistryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a registry in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.registry_service_pb2.UpdateRegistryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified registry."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.registry_service_pb2.DeleteRegistryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified registry."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the specified registry.
    """

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified registry."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified registry."""

    ListIpPermission: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.registry_service_pb2.ListIpPermissionRequest,
        yandex.cloud.containerregistry.v1.registry_service_pb2.ListIpPermissionsResponse,
    ]
    """ip permissions

    List ip permissions for the specified registry.
    """

    SetIpPermission: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.registry_service_pb2.SetIpPermissionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Set ip permissions for the specified registry."""

    UpdateIpPermission: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.registry_service_pb2.UpdateIpPermissionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update ip permissions for the specified registry."""

class RegistryServiceAsyncStub:
    """A set of methods for managing Registry resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.registry_service_pb2.GetRegistryRequest,
        yandex.cloud.containerregistry.v1.registry_pb2.Registry,
    ]
    """Returns the specified Registry resource.

    To get the list of available Registry resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.registry_service_pb2.ListRegistriesRequest,
        yandex.cloud.containerregistry.v1.registry_service_pb2.ListRegistriesResponse,
    ]
    """Retrieves the list of Registry resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.registry_service_pb2.CreateRegistryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a registry in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.registry_service_pb2.UpdateRegistryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified registry."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.registry_service_pb2.DeleteRegistryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified registry."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the specified registry.
    """

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified registry."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified registry."""

    ListIpPermission: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.registry_service_pb2.ListIpPermissionRequest,
        yandex.cloud.containerregistry.v1.registry_service_pb2.ListIpPermissionsResponse,
    ]
    """ip permissions

    List ip permissions for the specified registry.
    """

    SetIpPermission: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.registry_service_pb2.SetIpPermissionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Set ip permissions for the specified registry."""

    UpdateIpPermission: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.registry_service_pb2.UpdateIpPermissionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update ip permissions for the specified registry."""

class RegistryServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Registry resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.containerregistry.v1.registry_service_pb2.GetRegistryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.registry_pb2.Registry, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.registry_pb2.Registry]]:
        """Returns the specified Registry resource.

        To get the list of available Registry resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.containerregistry.v1.registry_service_pb2.ListRegistriesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.registry_service_pb2.ListRegistriesResponse, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.registry_service_pb2.ListRegistriesResponse]]:
        """Retrieves the list of Registry resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.containerregistry.v1.registry_service_pb2.CreateRegistryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a registry in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.containerregistry.v1.registry_service_pb2.UpdateRegistryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified registry."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.containerregistry.v1.registry_service_pb2.DeleteRegistryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified registry."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """access

        Lists access bindings for the specified registry.
        """

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the specified registry."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified registry."""

    @abc.abstractmethod
    def ListIpPermission(
        self,
        request: yandex.cloud.containerregistry.v1.registry_service_pb2.ListIpPermissionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.registry_service_pb2.ListIpPermissionsResponse, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.registry_service_pb2.ListIpPermissionsResponse]]:
        """ip permissions

        List ip permissions for the specified registry.
        """

    @abc.abstractmethod
    def SetIpPermission(
        self,
        request: yandex.cloud.containerregistry.v1.registry_service_pb2.SetIpPermissionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Set ip permissions for the specified registry."""

    @abc.abstractmethod
    def UpdateIpPermission(
        self,
        request: yandex.cloud.containerregistry.v1.registry_service_pb2.UpdateIpPermissionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Update ip permissions for the specified registry."""

def add_RegistryServiceServicer_to_server(servicer: RegistryServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.compute.v1.snapshot_schedule_pb2
import yandex.cloud.compute.v1.snapshot_schedule_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SnapshotScheduleServiceStub:
    """A set of methods for managing snapshot schedules."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.GetSnapshotScheduleRequest,
        yandex.cloud.compute.v1.snapshot_schedule_pb2.SnapshotSchedule,
    ]
    """Returns the specified snapshot schedule.

    To get the list of available snapshot schedules, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotSchedulesRequest,
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotSchedulesResponse,
    ]
    """Retrieves the list of snapshot schedules in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.CreateSnapshotScheduleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a snapshot schedule in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.UpdateSnapshotScheduleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified snapshot schedule.

    The schedule is updated only after all snapshot creations and deletions triggered by the schedule are completed.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.DeleteSnapshotScheduleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified snapshot schedule.

    Deleting a snapshot schedule removes its data permanently and is irreversible. However, deleting a schedule
    does not delete any snapshots created by the schedule. You must delete snapshots separately.

    The schedule is deleted only after all snapshot creations and deletions triggered by the schedule are completed.
    """

    UpdateDisks: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.UpdateSnapshotScheduleDisksRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the list of disks attached to the specified schedule.

    The schedule is updated only after all snapshot creations and deletions triggered by the schedule are completed.
    """

    Disable: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.DisableSnapshotScheduleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Disables the specified snapshot schedule.

    The [SnapshotSchedule.status] is changed to `INACTIVE`: the schedule is interrupted, snapshots won't be created
    or deleted.

    The schedule is disabled only after all snapshot creations and deletions triggered by the schedule are completed.
    """

    Enable: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.EnableSnapshotScheduleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Enables the specified snapshot schedule.

    The [SnapshotSchedule.status] is changed to `ACTIVE`: new disk snapshots will be created, old ones deleted
    (if [SnapshotSchedule.retention_policy] is specified).
    """

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleOperationsRequest,
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleOperationsResponse,
    ]
    """Lists operations for the specified snapshot schedule."""

    ListSnapshots: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleSnapshotsRequest,
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleSnapshotsResponse,
    ]
    """Retrieves the list of snapshots created by the specified snapshot schedule."""

    ListDisks: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleDisksRequest,
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleDisksResponse,
    ]
    """Retrieves the list of disks attached to the specified snapshot schedule."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the snapshot schedule.
    """

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the snapshot schedule."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the snapshot schedule."""

class SnapshotScheduleServiceAsyncStub:
    """A set of methods for managing snapshot schedules."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.GetSnapshotScheduleRequest,
        yandex.cloud.compute.v1.snapshot_schedule_pb2.SnapshotSchedule,
    ]
    """Returns the specified snapshot schedule.

    To get the list of available snapshot schedules, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotSchedulesRequest,
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotSchedulesResponse,
    ]
    """Retrieves the list of snapshot schedules in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.CreateSnapshotScheduleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a snapshot schedule in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.UpdateSnapshotScheduleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified snapshot schedule.

    The schedule is updated only after all snapshot creations and deletions triggered by the schedule are completed.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.DeleteSnapshotScheduleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified snapshot schedule.

    Deleting a snapshot schedule removes its data permanently and is irreversible. However, deleting a schedule
    does not delete any snapshots created by the schedule. You must delete snapshots separately.

    The schedule is deleted only after all snapshot creations and deletions triggered by the schedule are completed.
    """

    UpdateDisks: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.UpdateSnapshotScheduleDisksRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the list of disks attached to the specified schedule.

    The schedule is updated only after all snapshot creations and deletions triggered by the schedule are completed.
    """

    Disable: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.DisableSnapshotScheduleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Disables the specified snapshot schedule.

    The [SnapshotSchedule.status] is changed to `INACTIVE`: the schedule is interrupted, snapshots won't be created
    or deleted.

    The schedule is disabled only after all snapshot creations and deletions triggered by the schedule are completed.
    """

    Enable: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.EnableSnapshotScheduleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Enables the specified snapshot schedule.

    The [SnapshotSchedule.status] is changed to `ACTIVE`: new disk snapshots will be created, old ones deleted
    (if [SnapshotSchedule.retention_policy] is specified).
    """

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleOperationsRequest,
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleOperationsResponse,
    ]
    """Lists operations for the specified snapshot schedule."""

    ListSnapshots: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleSnapshotsRequest,
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleSnapshotsResponse,
    ]
    """Retrieves the list of snapshots created by the specified snapshot schedule."""

    ListDisks: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleDisksRequest,
        yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleDisksResponse,
    ]
    """Retrieves the list of disks attached to the specified snapshot schedule."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the snapshot schedule.
    """

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the snapshot schedule."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the snapshot schedule."""

class SnapshotScheduleServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing snapshot schedules."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.compute.v1.snapshot_schedule_service_pb2.GetSnapshotScheduleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.snapshot_schedule_pb2.SnapshotSchedule, collections.abc.Awaitable[yandex.cloud.compute.v1.snapshot_schedule_pb2.SnapshotSchedule]]:
        """Returns the specified snapshot schedule.

        To get the list of available snapshot schedules, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotSchedulesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotSchedulesResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotSchedulesResponse]]:
        """Retrieves the list of snapshot schedules in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.compute.v1.snapshot_schedule_service_pb2.CreateSnapshotScheduleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a snapshot schedule in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.compute.v1.snapshot_schedule_service_pb2.UpdateSnapshotScheduleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified snapshot schedule.

        The schedule is updated only after all snapshot creations and deletions triggered by the schedule are completed.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.compute.v1.snapshot_schedule_service_pb2.DeleteSnapshotScheduleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified snapshot schedule.

        Deleting a snapshot schedule removes its data permanently and is irreversible. However, deleting a schedule
        does not delete any snapshots created by the schedule. You must delete snapshots separately.

        The schedule is deleted only after all snapshot creations and deletions triggered by the schedule are completed.
        """

    @abc.abstractmethod
    def UpdateDisks(
        self,
        request: yandex.cloud.compute.v1.snapshot_schedule_service_pb2.UpdateSnapshotScheduleDisksRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the list of disks attached to the specified schedule.

        The schedule is updated only after all snapshot creations and deletions triggered by the schedule are completed.
        """

    @abc.abstractmethod
    def Disable(
        self,
        request: yandex.cloud.compute.v1.snapshot_schedule_service_pb2.DisableSnapshotScheduleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Disables the specified snapshot schedule.

        The [SnapshotSchedule.status] is changed to `INACTIVE`: the schedule is interrupted, snapshots won't be created
        or deleted.

        The schedule is disabled only after all snapshot creations and deletions triggered by the schedule are completed.
        """

    @abc.abstractmethod
    def Enable(
        self,
        request: yandex.cloud.compute.v1.snapshot_schedule_service_pb2.EnableSnapshotScheduleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Enables the specified snapshot schedule.

        The [SnapshotSchedule.status] is changed to `ACTIVE`: new disk snapshots will be created, old ones deleted
        (if [SnapshotSchedule.retention_policy] is specified).
        """

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleOperationsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleOperationsResponse]]:
        """Lists operations for the specified snapshot schedule."""

    @abc.abstractmethod
    def ListSnapshots(
        self,
        request: yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleSnapshotsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleSnapshotsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleSnapshotsResponse]]:
        """Retrieves the list of snapshots created by the specified snapshot schedule."""

    @abc.abstractmethod
    def ListDisks(
        self,
        request: yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleDisksRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleDisksResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.snapshot_schedule_service_pb2.ListSnapshotScheduleDisksResponse]]:
        """Retrieves the list of disks attached to the specified snapshot schedule."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """access

        Lists access bindings for the snapshot schedule.
        """

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the snapshot schedule."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the snapshot schedule."""

def add_SnapshotScheduleServiceServicer_to_server(servicer: SnapshotScheduleServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.os_login_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class OsLoginServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    GetSettings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.GetOsLoginSettingsRequest,
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.OsLoginSettings,
    ]
    """OsLogin settings"""

    UpdateSettings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.UpdateOsLoginSettingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    GetProfile: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.GetOsLoginProfileRequest,
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.OsLoginProfile,
    ]
    """OsLogin Profiles"""

    ListProfiles: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.ListOsLoginProfilesRequest,
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.ListOsLoginProfilesResponse,
    ]

    CreateProfile: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.CreateOsLoginProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    UpdateProfile: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.UpdateOsLoginProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    SetDefaultProfile: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.SetDefaultOsLoginProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets a profile as a default for the subject assigned to this profile"""

    DeleteProfile: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.DeleteOsLoginProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

class OsLoginServiceAsyncStub:
    GetSettings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.GetOsLoginSettingsRequest,
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.OsLoginSettings,
    ]
    """OsLogin settings"""

    UpdateSettings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.UpdateOsLoginSettingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    GetProfile: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.GetOsLoginProfileRequest,
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.OsLoginProfile,
    ]
    """OsLogin Profiles"""

    ListProfiles: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.ListOsLoginProfilesRequest,
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.ListOsLoginProfilesResponse,
    ]

    CreateProfile: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.CreateOsLoginProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    UpdateProfile: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.UpdateOsLoginProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    SetDefaultProfile: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.SetDefaultOsLoginProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets a profile as a default for the subject assigned to this profile"""

    DeleteProfile: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.os_login_service_pb2.DeleteOsLoginProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

class OsLoginServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetSettings(
        self,
        request: yandex.cloud.organizationmanager.v1.os_login_service_pb2.GetOsLoginSettingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.os_login_service_pb2.OsLoginSettings, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.os_login_service_pb2.OsLoginSettings]]:
        """OsLogin settings"""

    @abc.abstractmethod
    def UpdateSettings(
        self,
        request: yandex.cloud.organizationmanager.v1.os_login_service_pb2.UpdateOsLoginSettingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

    @abc.abstractmethod
    def GetProfile(
        self,
        request: yandex.cloud.organizationmanager.v1.os_login_service_pb2.GetOsLoginProfileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.os_login_service_pb2.OsLoginProfile, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.os_login_service_pb2.OsLoginProfile]]:
        """OsLogin Profiles"""

    @abc.abstractmethod
    def ListProfiles(
        self,
        request: yandex.cloud.organizationmanager.v1.os_login_service_pb2.ListOsLoginProfilesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.os_login_service_pb2.ListOsLoginProfilesResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.os_login_service_pb2.ListOsLoginProfilesResponse]]: ...

    @abc.abstractmethod
    def CreateProfile(
        self,
        request: yandex.cloud.organizationmanager.v1.os_login_service_pb2.CreateOsLoginProfileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

    @abc.abstractmethod
    def UpdateProfile(
        self,
        request: yandex.cloud.organizationmanager.v1.os_login_service_pb2.UpdateOsLoginProfileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

    @abc.abstractmethod
    def SetDefaultProfile(
        self,
        request: yandex.cloud.organizationmanager.v1.os_login_service_pb2.SetDefaultOsLoginProfileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets a profile as a default for the subject assigned to this profile"""

    @abc.abstractmethod
    def DeleteProfile(
        self,
        request: yandex.cloud.organizationmanager.v1.os_login_service_pb2.DeleteOsLoginProfileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

def add_OsLoginServiceServicer_to_server(servicer: OsLoginServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
